==> ses-1.60.0-sources.jar: software/amazon/awscdk/services/ses/CfnReceiptRuleSetProps.java <==
package software.amazon.awscdk.services.ses;

/**
 * Properties for defining a `AWS::SES::ReceiptRuleSet`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptruleset.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.447Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.CfnReceiptRuleSetProps")
@software.amazon.jsii.Jsii.Proxy(CfnReceiptRuleSetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnReceiptRuleSetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::SES::ReceiptRuleSet.RuleSetName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ses-receiptruleset.html#cfn-ses-receiptruleset-rulesetname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getRuleSetName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnReceiptRuleSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnReceiptRuleSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnReceiptRuleSetProps> {
        private java.lang.String ruleSetName;

        /**
         * Sets the value of {@link CfnReceiptRuleSetProps#getRuleSetName}
         * @param ruleSetName `AWS::SES::ReceiptRuleSet.RuleSetName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleSetName(java.lang.String ruleSetName) {
            this.ruleSetName = ruleSetName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnReceiptRuleSetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnReceiptRuleSetProps build() {
            return new Jsii$Proxy(ruleSetName);
        }
    }

    /**
     * An implementation for {@link CfnReceiptRuleSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnReceiptRuleSetProps {
        private final java.lang.String ruleSetName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ruleSetName = this.jsiiGet("ruleSetName", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String ruleSetName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ruleSetName = ruleSetName;
        }

        @Override
        public java.lang.String getRuleSetName() {
            return this.ruleSetName;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRuleSetName() != null) {
                data.set("ruleSetName", om.valueToTree(this.getRuleSetName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.CfnReceiptRuleSetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnReceiptRuleSetProps.Jsii$Proxy that = (CfnReceiptRuleSetProps.Jsii$Proxy) o;

            return this.ruleSetName != null ? this.ruleSetName.equals(that.ruleSetName) : that.ruleSetName == null;
        }

        @Override
        public int hashCode() {
            int result = this.ruleSetName != null ? this.ruleSetName.hashCode() : 0;
            return result;
        }
    }
}

==> ses-1.173.0-sources.jar: software/amazon/awscdk/services/ses/CfnReceiptRuleSetProps.java <==
package software.amazon.awscdk.services.ses;

/**
 * Properties for defining a `CfnReceiptRuleSet`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ses.*;
 * CfnReceiptRuleSetProps cfnReceiptRuleSetProps = CfnReceiptRuleSetProps.builder()
 *         .ruleSetName("ruleSetName")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:30.634Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.CfnReceiptRuleSetProps")
@software.amazon.jsii.Jsii.Proxy(CfnReceiptRuleSetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnReceiptRuleSetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the receipt rule set to reorder.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getRuleSetName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnReceiptRuleSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnReceiptRuleSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnReceiptRuleSetProps> {
        java.lang.String ruleSetName;

        /**
         * Sets the value of {@link CfnReceiptRuleSetProps#getRuleSetName}
         * @param ruleSetName The name of the receipt rule set to reorder.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleSetName(java.lang.String ruleSetName) {
            this.ruleSetName = ruleSetName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnReceiptRuleSetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnReceiptRuleSetProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnReceiptRuleSetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnReceiptRuleSetProps {
        private final java.lang.String ruleSetName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ruleSetName = software.amazon.jsii.Kernel.get(this, "ruleSetName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ruleSetName = builder.ruleSetName;
        }

        @Override
        public final java.lang.String getRuleSetName() {
            return this.ruleSetName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRuleSetName() != null) {
                data.set("ruleSetName", om.valueToTree(this.getRuleSetName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.CfnReceiptRuleSetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnReceiptRuleSetProps.Jsii$Proxy that = (CfnReceiptRuleSetProps.Jsii$Proxy) o;

            return this.ruleSetName != null ? this.ruleSetName.equals(that.ruleSetName) : that.ruleSetName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ruleSetName != null ? this.ruleSetName.hashCode() : 0;
            return result;
        }
    }
}
